@@ -8,6 +8,8 @@ from os import listdir, mkdir
 from os.path import isdir, join, splitext
 from osgeo import gdal, ogr
 import tensorflow as tf
+from tensorflow.keras.layers.experimental import preprocessing
+from tensorflow.keras.models import Sequential
 
 
 class SegmentationDataset:
@@ -255,21 +257,6 @@ class SegmentationDataset:
             if verbose:
                 print(filename + " tiles generated.")
 
-    def get_label_polygons(self) -> None:
-        """Queries the OpenStreetMaps API and downloads polygon data over the source imagery.
-
-        Returns:
-            None
-        """
-
-        # check whether the source imagery directory has been set and is nonempty.
-        self.check_polygons()
-
-        # loop through the source files
-        # for filename in self.data_names:
-
-        # raise NotImplementedError("Method \'get_label_polygons\' not implemented.")
-
     def rasterize_polygon_layers(self, verbose=True) -> None:
         """Generates label rasters from the polygon data, with dimensions matching the source imagery.
 
@@ -369,9 +356,8 @@ class SegmentationDataset:
         self.check_polygons()
 
     def tf_dataset(self, n_classes: int = 2,
-                   flip_vertically: bool = True,
-                   rotate: bool = True,
-                   scale_factor: float = 1 / 255,
+                   augment = True,
+                   batch_size: int = 1,
                    perform_one_hot: bool = False) -> tf.data.Dataset:
 
         """Creates a tf.data.Dataset object which generates batches from the tile folders.
@@ -394,7 +380,7 @@ class SegmentationDataset:
         if self.tile_dimension == 0:
             raise Exception("The tile_generator attribute must be greater than 0.")
 
-        # first, define a generator
+        # first, define a generator object which will define a tf.data.Dataset
         def generator():
             filenames = listdir(join(self.tiles_path, "imagery"))
             train_ids = range(len(filenames))
@@ -407,33 +393,45 @@ class SegmentationDataset:
                     # reshape img to channels-last
                     img = moveaxis(img, 0, -1)
 
-                    # perform random rotation
-                    if rotate:
-                        k_rot = randint(0, 4)
-                        img = rot90(img, k=k_rot)
-                        lbl = rot90(lbl, k=k_rot)
-
-                    # perform random flip
-                    if flip_vertically and randint(0, 2) == 1:
-                        img = flip(img, axis=0)
-                        lbl = flip(lbl, axis=0)
-
                     # perform a one-hot encoding of the labels
                     if perform_one_hot:
                         lbl = convert_labels_to_one_hots(lbl, n_classes)
 
-                    # rescale the input pixels
-                    img = img * scale_factor
-
                     yield img, lbl
 
         # create the tf.data.Dataset object
+        if perform_one_hot:
+            output_signature = (
+                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, self.n_channels), dtype=tf.float32),
+                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, n_classes), dtype=tf.float32))
+        else:
+            output_signature = (
+                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, self.n_channels), dtype=tf.float32),
+                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension), dtype=tf.float32))
+
         tf_ds = tf.data.Dataset.from_generator(
             generator,
             args=[],
-            output_signature=(
-                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension, self.n_channels), dtype=tf.float32),
-                tf.TensorSpec(shape=(self.tile_dimension, self.tile_dimension), dtype=tf.float32))
-        )
+            output_signature=output_signature)
+
+        # do data augmentation
+        if augment:
+            ds_aug = Sequential([preprocessing.Rescaling(1.0 / 255),
+                                 preprocessing.RandomFlip('horizontal_and_vertical')])
+
+            tf_ds = (
+                tf_ds
+                .shuffle(2 * batch_size)
+                .batch(batch_size)
+                .map(lambda x, y: (ds_aug(x), y),
+                     num_parallel_calls=tf.data.AUTOTUNE)
+                .prefetch(tf.data.AUTOTUNE)
+            )
+        else:
+            tf_ds = (
+                tf_ds
+                .batch(batch_size)
+                .prefetch(tf.data.AUTOTUNE)
+            )
 
         return tf_ds
