@@ -161,84 +161,6 @@ class Unet(SegmentationModel):
         self.n_filters = n_filters
         self.dropout_rate = dropout_rate
 
-        # define all the Unet layers
-
-        # Downsampling-path convolutional layers
-        self.inputs = Input(shape=(None, None, n_channels))
-
-        self.conv_down_0 = [Conv2D(filters=self.n_filters,
-                                   kernel_size=(3, 3),
-                                   padding='same',
-                                   activation='relu') for i in range(2)]
-
-        self.conv_down_1 = [Conv2D(filters=2 * self.n_filters,
-                                   kernel_size=(3, 3),
-                                   padding='same',
-                                   activation='relu') for i in range(2)]
-
-        self.conv_down_2 = [Conv2D(filters=4 * self.n_filters,
-                                   kernel_size=(3, 3),
-                                   padding='same',
-                                   activation='relu') for i in range(4)]
-
-        self.conv_down_3 = [Conv2D(filters=8 * self.n_filters,
-                                   kernel_size=(3, 3),
-                                   padding='same',
-                                   activation='relu') for i in range(4)]
-
-        self.conv_down_4 = [Conv2D(filters=8 * self.n_filters,
-                                   kernel_size=(3, 3),
-                                   padding='same',
-                                   activation='relu') for i in range(4)]
-
-        self.conv_up_3 = [Conv2D(filters=8 * self.n_filters,
-                                 kernel_size=(3, 3),
-                                 padding='same',
-                                 activation='relu') for i in range(4)]
-
-        self.conv_up_2 = [Conv2D(filters=4 * self.n_filters,
-                                 kernel_size=(3, 3),
-                                 padding='same',
-                                 activation='relu') for i in range(4)]
-
-        self.conv_up_1 = [Conv2D(filters=2 * self.n_filters,
-                                 kernel_size=(3, 3),
-                                 padding='same',
-                                 activation='relu') for i in range(2)]
-
-        self.conv_up_0 = [Conv2D(filters=8 * self.n_filters,
-                                 kernel_size=(3, 3),
-                                 padding='same',
-                                 activation='relu') for i in range(2)]
-
-        self.conv_final = Conv2D(filters=self.n_classes,
-                                 kernel_size=(1, 1),
-                                 padding='same',
-                                 activation='softmax')
-
-        # Compute how many dropout and batch-normalization layers are needed
-        n_do_bn = len(self.conv_down_0 + self.conv_up_0 +
-                      self.conv_down_1 + self.conv_up_1 +
-                      self.conv_down_2 + self.conv_up_2 +
-                      self.conv_down_3 + self.conv_up_3 +
-                      self.conv_down_4)
-
-        # Max-pooling layers
-        self.max_pooling = [MaxPooling2D(pool_size=(2, 2),
-                                         padding='same') for i in range(4)]
-
-        # Upsampling layers
-        self.upsampling = [UpSampling2D(size=(2, 2)) for i in range(4)]
-
-        # Batch normalization layers
-        self.batch_normalization = [BatchNormalization() for i in range(n_do_bn)]
-
-        # Dropout layers
-        self.dropout = [Dropout(rate=self.dropout_rate) for i in range(n_do_bn)]
-
-        # Concatenate layers
-        self.concatenate = [Concatenate(axis=-1) for i in range(4)]
-
     def compile_model(self, loss: tf.keras.losses.Loss = 'sparse_categorical_crossentropy',
                       learning_rate: float = 0.0001) -> None:
 
